@@ -23,6 +23,8 @@
 
 package ch.kuramo.javie.app.player;
 
+import java.util.concurrent.atomic.AtomicInteger;
+
 import org.eclipse.core.runtime.ListenerList;
 import org.eclipse.jface.resource.ImageRegistry;
 import org.eclipse.swt.SWT;
@@ -35,12 +37,15 @@ import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Image;
+import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Event;
+import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Scale;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -188,23 +193,112 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 			}
 		});
 
-		prevButton.addSelectionListener(new SelectionAdapter() {
-			public void widgetSelected(SelectionEvent e) {
-				setFrameNumber(_scale.getSelection() - 1);
-			}
-		});
-
-		nextButton.addSelectionListener(new SelectionAdapter() {
-			public void widgetSelected(SelectionEvent e) {
-				setFrameNumber(_scale.getSelection() + 1);
-			}
-		});
-
 		lastButton.addSelectionListener(new SelectionAdapter() {
 			public void widgetSelected(SelectionEvent e) {
 				setFrameNumber(_scale.getMaximum());
 			}
 		});
+
+		class PrevNextButtonTracker extends MouseAdapter implements PlayerThreadListener, Listener {
+
+			private int incrDecr;
+
+			private long mouseDownTime = -1;
+
+			private boolean mouseIsInside;
+
+			private AtomicInteger frameNumber = new AtomicInteger(-1);
+
+			PrevNextButtonTracker(boolean prev) {
+				incrDecr = prev ? -1 : 1;
+			}
+
+			public void mouseDown(MouseEvent e) {
+				if (e.button == 1) {
+					mouseDownTime = System.currentTimeMillis();
+					mouseIsInside = true;
+
+					if (_videoCanvas != null) {
+						_videoCanvas.addPlayerThreadListener(this);
+						incrDecr = (incrDecr > 0) ? 1 : -1;
+					} else {
+						_audioThread.addPlayerThreadListener(this);
+						incrDecr = (incrDecr > 0) ? 4800 : -4800;
+					}
+
+					e.display.addFilter(SWT.MouseMove, this);
+					e.display.addFilter(SWT.MouseUp, this);
+					e.display.addFilter(SWT.Deactivate, this);
+
+					if (_timeKeeper != null && !_timeKeeper.isPaused()) {
+						pause();
+					} else {
+						MediaPlayer.this.setFrameNumber(_scale.getSelection() + incrDecr);
+					}
+				}
+			}
+
+			public void threadRender(PlayerThreadEvent event) {
+				frameNumber.set((int)event.time.toFrameNumber(_frameDuration));
+				getDisplay().asyncExec(new Runnable() {
+					public void run() {
+						if (mouseDownTime >= 0) {
+							long t = System.currentTimeMillis();
+							int fn;
+							if (t-mouseDownTime >= 500 && mouseIsInside && (fn = frameNumber.getAndSet(-1)) >= 0) {
+								setFrameNumber(fn + incrDecr);
+							} else {
+								getDisplay().timerExec((int)(500-(t-mouseDownTime)), this);
+							}
+						}
+					}
+				});
+			}
+
+			public void threadEndOfDuration(PlayerThreadEvent event) {
+				// nothing to do
+			}
+
+			public void handleEvent(Event e) {
+				switch (e.type) {
+					case SWT.MouseMove: {
+						boolean oldInside = mouseIsInside;
+						Point size = ((Button)e.widget).getSize();
+						mouseIsInside = (e.x >= 0 && e.x < size.x && e.y >= 0 && e.y < size.y);
+
+						int fn;
+						if (!oldInside && mouseIsInside && (fn = frameNumber.getAndSet(-1)) >= 0) {
+							setFrameNumber(fn + incrDecr);
+						}
+						break;
+					}
+					case SWT.MouseUp:
+					case SWT.Deactivate:
+						mouseDownTime = -1;
+						mouseIsInside = false;
+
+						if (_videoCanvas != null) {
+							_videoCanvas.removePlayerThreadListener(this);
+						} else {
+							_audioThread.removePlayerThreadListener(this);
+						}
+
+						e.display.removeFilter(SWT.MouseMove, this);
+						e.display.removeFilter(SWT.MouseUp, this);
+						e.display.removeFilter(SWT.Deactivate, this);
+						break;
+				}
+			}
+
+			private void setFrameNumber(int frameNumber) {
+				if (frameNumber >= 0 && frameNumber <= _scale.getMaximum()) {
+					MediaPlayer.this.setFrameNumber(frameNumber);
+				}
+			}
+		}
+
+		prevButton.addMouseListener(new PrevNextButtonTracker(true));
+		nextButton.addMouseListener(new PrevNextButtonTracker(false));
 	}
 
 	public void close() {
