@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -36,6 +36,9 @@ import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.atomic.AtomicReference;
 
 import javax.media.opengl.DebugGL2;
+import javax.media.opengl.DebugGL3bc;
+import javax.media.opengl.DebugGL4bc;
+import javax.media.opengl.GL;
 import javax.media.opengl.GL2;
 import javax.media.opengl.GLAutoDrawable;
 import javax.media.opengl.GLContext;
@@ -82,7 +85,7 @@ import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.RenderContext;
 
 import com.google.inject.Inject;
-import com.sun.opengl.util.gl2.GLUT;
+import com.jogamp.opengl.util.gl2.GLUT;
 
 public class VideoCanvas extends Thread implements GLEventListener {
 
@@ -157,7 +160,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 	@Inject
 	private GLGlobal _glGlobal;
 
-//	private final boolean _intel;
+	private final boolean _intel;
 
 	private final AtiIntelLock _atiIntelLock;
 
@@ -175,6 +178,9 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 		InjectorHolder.getInjector().injectMembers(this);
 
+		_intel = _glGlobal.isIntel();
+		_atiIntelLock = AtiIntelLock.get(_glGlobal);
+
 		_mediaItem = mediaItem;
 		_mediaInput = mediaInput;
 		_timeKeeper = timeKeeper;
@@ -193,9 +199,6 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		}
 
 		setZoom(1.0);
-
-//		_intel = _glGlobal.isIntel();
-		_atiIntelLock = AtiIntelLock.get(_glGlobal);
 	}
 
 	public Control getControl() {
@@ -576,10 +579,18 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 		_context.activate();
 		try {
-			// TODO DebugGLの使用をやめる。でも当分はこのままにしておく。
 			_context.getGL(); // これをしておかないとRenderContext内でOpenGL関連の初期化が行われず、次のGLContext.getCurrent()がnullになる。
 			GLContext glContext = GLContext.getCurrent();
-			glContext.setGL(new DebugGL2(glContext.getGL().getGL2()));
+
+			// TODO DebugGLの使用をやめる。でも当分はこのままにしておく。
+			GL downstreamGL = glContext.getGL();
+			if (downstreamGL.isGL4bc()) {
+				glContext.setGL(new DebugGL4bc(downstreamGL.getGL4bc()));
+			} else if (downstreamGL.isGL3bc()) {
+				glContext.setGL(new DebugGL3bc(downstreamGL.getGL3bc()));
+			} else {
+				glContext.setGL(new DebugGL2(downstreamGL.getGL2()));
+			}
 
 			GL2 gl = _context.getGL().getGL2();
 
@@ -839,10 +850,10 @@ public class VideoCanvas extends Thread implements GLEventListener {
 	}
 
 	private void glFinish(GL2 gl, IVideoBuffer vb) {
-//		if (!_intel) {
-//			gl.glFinish();
-//			return;
-//		}
+		if (!_intel) {
+			gl.glFinish();
+			return;
+		}
 
 		// Intel GMAの場合、カラーバッファに何もアタッチされていないとglFinishに失敗する。
 		// (GMA X4500で確認) 
