@@ -110,7 +110,7 @@ public class ClearLayerKeyframesOperation<V> extends ProjectOperation {
 		} else {
 			restore(avalue);
 			if (pm != null) {
-				Collection<Keyframe<V>> keyframes = avalue.getKeyframes();
+				Collection<Keyframe<V>> keyframes = avalue.getKeyframeMap().values();
 				Object[][] data = new Object[keyframes.size()][];
 				int i = 0;
 				for (Keyframe<V> kf : keyframes) {
@@ -130,7 +130,7 @@ public class ClearLayerKeyframesOperation<V> extends ProjectOperation {
 			dst.reset(src.getStaticValue());
 			dst.setExpression(src.getExpression());
 
-			for (Keyframe<V> kf : src.getKeyframes()) {
+			for (Keyframe<V> kf : src.getKeyframeMap().values()) {
 				dst.putKeyframe(kf);
 			}
 
