@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -28,6 +28,6 @@ import ch.kuramo.javie.api.Time;
 
 public interface VectorMediaInput extends MediaInput {
 
-	void rasterize(IVideoBuffer resultBuffer, double[] mvMatrix, double[] prjMatrix, Time mediaTime);
+	void rasterize(IVideoBuffer resultBuffer, double[] prjMatrix, double[] mvMatrix, Time mediaTime);
 
 }
